Re-exports
pub use mpfs_pac as pac;
Modules
- ethernet
- gpio
- The MPFS broadly uses 2 GPIO interfaces: the MSS GPIO interface and the FPGA Core GPIO interface.
- log
- qspi
- spi
- uart
Macros
- impl_
gpio_ pin - This macro is used to define a GPIO pin.
- impl_
input_ peripheral - impl_
output_ peripheral - print_
unguarded - println
- println_
unguarded
Structs
- Mutex
- A Mutex that does not protect against interrupts, but does protect against other cores
- Printer
- Unguarded
Printer
Traits
Functions
- hart_id
- init_
logger - Initialize the logger with the given maximum log level.
- log_
task - low_
power_ loop_ forever - Put in a panic handler to put the core into a low power loop
- print_
panic