Crate mpfs_hal

Crate mpfs_hal 

Re-exports

pub use mpfs_pac as pac;

Modules

ethernet
gpio
The MPFS broadly uses 2 GPIO interfaces: the MSS GPIO interface and the FPGA Core GPIO interface.
qspi
spi
uart

Macros

impl_gpio_pin
This macro is used to define a GPIO pin.
impl_input_peripheral
impl_output_peripheral
print
print_unguarded
println
println_unguarded

Structs

Mutex
A Mutex that does not protect against interrupts, but does protect against other cores
Printer
UnguardedPrinter

Traits

Peripheral
PeripheralRef

Functions

hart_id
init_logger
Initialize the logger with the given maximum log level.
log_task
low_power_loop_forever
Put in a panic handler to put the core into a low power loop
print_panic

Attribute Macros

hart1_main
hart2_main
hart3_main
hart4_main
init_once